#include <Adafruit_NeoPixel.h>
#include <Adafruit_SSD1306.h>
#include <Wire.h>
#define SCREEN_WIDTH 128 
#define SCREEN_HEIGHT 64 
#define OLED_RESET     -1 
#define SCREEN_ADDRESS 0x3C 
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

const int buttonPin = 4; 
int buttonState, buttonStateOld = HIGH;
int motionSensor = 2, motionState, motionStateOld;
int ledcounter = 16;
int neopixel = 9;
int cupcounter = 0;
int i, cupsStanding;

Adafruit_NeoPixel lights(ledcounter, neopixel, NEO_GRB + NEO_KHZ800);


void setup() {
  // put your setup code here, to run once:
  Serial.begin(115200);
  Wire.begin(6, 7);

  pinMode(buttonPin, INPUT);
  pinMode(motionSensor, INPUT);

  //lights.setBrigthness(200);
  lights.begin();

  if (!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS)) {
    Serial.println(F("SSD1306 allocation failed"));
    for (;;); // Don't proceed, loop forever
  }

  display.clearDisplay();
  display.setTextSize(1);           
  display.setTextColor(SSD1306_WHITE);      
  display.setCursor(0,0); 
  display.println("Off to a game of beer pong!");
  display.display();

  lights.clear();
  for (int i = 0; i < ledcounter; i++) 
  {
    lights.setPixelColor(i, lights.Color(82, 136, 136));
    lights.show();  
    delay(100);
  }
  lights.clear();
  lights.show();

}

void loop() {
  buttonState = digitalRead(buttonPin);
  motionState = digitalRead(motionSensor);

  if(buttonState != buttonStateOld){
    if(buttonState == LOW){
       i++;
       if(i>1){
       Serial.println("Button clicked. Seems like you got hit");
       got_hit();
       counting_cups();
       }
    }
    
    buttonStateOld = buttonState;
  }

  if(motionState != motionStateOld){
    if(motionState == HIGH){
      Serial.println("Motion detected. We consider it a hit.");
      got_hit();
      counting_cups();
    }

    motionStateOld = motionState;
  }

  delay(100); // this speeds up the simulation
}

void counting_cups(){
  cupcounter ++;

  generate_motivation(cupcounter);
}

void generate_motivation(int a){
  switch(cupcounter){
    case 1:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("if this is what the start looks like, I don't want to see the end.");
      display.display();
      set_lights(cupcounter);
      break;
    case 2:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("it looks like your opponents are starting to warm up. maybe that's not even a good thing.");
      display.display();
      set_lights(cupcounter);
      break;
    case 3: 
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("every beginning is difficult, but slowly it becomes uncomfortable.");
      display.display();
      set_lights(cupcounter);
      break;
    case 4:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("if you keep playing like this, you’ll soon just be drinking out of frustration.");
      display.display();
      set_lights(cupcounter);
      break;
    case 5:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("no pressure, but you're about to lose.");
      display.display();
      set_lights(cupcounter);
      break;
    case 6: 
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("statistically speaking, you now have even fewer chances.");
      display.display();
      set_lights(cupcounter);
      break;
    case 7: 
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("maybe throwing isn't your thing... try drinking");
      display.display();
      set_lights(cupcounter);
      break;
    case 8:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("that doesn’t look good. So for you.");
      display.display();
      set_lights(cupcounter);
      break;
    case 9:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("diamonds are created under pressure - or sometimes just excuses.");
      display.display();
      set_lights(cupcounter);
      break;
    case 10:
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("what a defeat! sometimes you lose, sometimes the others win. don't get discouraged, it has to work at some point.");
      display.display();
      set_lights(cupcounter);
      break;
    case 11: 
      display.clearDisplay();
      display.setCursor(0,0); 
      display.println("no problem if you want to get right back to losing - just keep it up! Here comes the next round.");
      display.display();

      cupcounter = 0;
      set_lights(cupcounter);
      break;
  }
  
}


void got_hit(){
    lights.clear();
  for (int i = 0; i < ledcounter; i++) 
  {
    lights.setPixelColor(i, lights.Color(255, 255, 255));
    lights.show();  
    delay(10);
  }
  lights.clear();
  lights.show();

  for (int i = 0; i < ledcounter; i++) 
  {
    lights.setPixelColor(i, lights.Color(255, 255, 255));
    lights.show();  
    delay(10);
  }
  lights.clear();
  lights.show();
  }


void set_lights(int a){
  lights.clear();
  cupsStanding = 10 - cupcounter;

  for (int i = 0; i < cupsStanding; i++) 
  {
    lights.setPixelColor(i, lights.Color(255, 0, 0));
    lights.show();  
    delay(100);
  }
}